<?php
use \GatewayWorker\Lib\Gateway;
use \GatewayWorker\Lib\Db;

class Events
{
	public static function onWorkerStart($businessWorker)
	{
		require_once __DIR__ . '/func.php';
	}
	public static function onMessage($client_id, $data) {
		global $db;
		$message = json_decode($data, true);
		$message_type = $message['type'];
		switch($message_type) {
			case 'init':
				if(!$message['id'] || !$message['from']) return;
				
				$uid = (string)$message['id'];
				$fromid = $message['from'].'_'.$uid;
				
				// 通知当前客户端初始化
				$init_message = array(
					'message_type' => 'init'
				);
				Gateway::sendToClient($client_id, json_encode($init_message));
				// 设置session
				$_SESSION = array(
					'from' => $message['from'],
					'username' => $message['username'],
					'avatar' => $message['avatar'],
					'id' => $uid,
					'sign' => $message['sign'],
					'ip' => $_SERVER['REMOTE_ADDR'],
					'time' => time(),
				);
				// 将当前链接与uid绑定
				Gateway::bindUid($client_id, $fromid);
				// 让当前客户端加入群组
				Gateway::joinGroup($client_id, $message['from']); //按客户来源域名分组
				Gateway::joinGroup($client_id, $message['from'].'_-1'); //按客户来源域名分组
				if($message['groupids']){
					foreach($message['groupids'] as $v){
						Gateway::joinGroup($client_id, $message['from'].'_'.$v);
					}
				}
				// 用户上线
				$status_message = array(
					'message_type' => 'online',
					'id' => $uid,
				);
				$_SESSION['online'] = 'online';
				Gateway::sendToGroup($message['from'], json_encode($status_message), $client_id);
				return;
			case 'chatMessage':
				// 聊天消息
				$mtype = 0;
				$type = $message['data']['to']['type'];
				$to_id = $message['data']['to']['id'];
				$fusername = str_addslashes($message['data']['to']['name']);
				$content = filter_str($message['data']['mine']['content']);
				$uid = $_SESSION['id'];
				$username = str_addslashes($_SESSION['username']);
				$from = $_SESSION['from'];
				$toid = $from.'_'.$to_id;
				$fromid = $from.'_'.$uid;
				$time = time();
				
				$cmd = stristr($content, " ", true);
				if(strtoupper($cmd) === '@SYS')
				{
					if($uid == 1){
						$content = stristr($content, " ");
						$mtype = 1;
					}
				}
				elseif(strtoupper($cmd) === '@ALL')
				{
					if($uid == 1){
						$content = stristr($content, " ");
						$mtype = 2;
					}
				}
				$msg = $content;
				$type = in_array($type, array('friend', 'group')) ? $type : 'friend';
				$status = $type == 'friend' ? (Gateway::isUidOnline($toid) ? 1 : 0) : 1;
				$msgid = $db->query("INSERT INTO ".TABLE_PRE."heart_im_msg (type,uid,username,fuid,fusername,domain,msg,time,status) VALUES ('$type',$uid,'$username',$to_id,'$fusername','$from','$msg',$time,$status)");
				
				$chat_message = array(
					'message_type' => 'chatMessage',
					'sendid' => $uid,
					'type' => $mtype,
					'data' => array(
						'msgid' => (int)$msgid,
						'userid' => $uid,
						'username' => $_SESSION['username'],
						'avatar' => $_SESSION['avatar'],
						'id' => $type == 'friend' ? $uid : $to_id,
						'type' => $type,
						'content' => nl2br(trim($content)),
						'timestamp'=> $time * 1000,
					)
				);
				
				if($mtype){
					$chat_message['message_type'] = 'notice';
					return Gateway::sendToGroup($from, json_encode($chat_message));
				}
				
				switch ($type) {
					// 私聊
					case 'friend':
						return Gateway::sendToUid($toid, json_encode($chat_message));
					// 群聊
					case 'group':
						return Gateway::sendToGroup($toid, json_encode($chat_message), $client_id);
				}
				return;
			case 'hide':
			case 'online':
				$status_message = array(
					'message_type' => $message_type,
					'id' => $_SESSION['id'],
				);
				$_SESSION['online'] = $message_type;
				Gateway::sendToGroup($_SESSION['from'], json_encode($status_message));
				return;
			case 'ping':
				return;
			default:
				return;
		}
	}
	
	public static function onClose($client_id) {
		$logout_message = array(
			'message_type' => 'logout',
			'id' => $_SESSION['id']
		);
		Gateway::sendToGroup($_SESSION['from'], json_encode($logout_message));
	}
}
